@@ -6,35 +6,6 @@ from snapshottest import Snapshot
 
 snapshots = Snapshot()
 
-snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[asset_aware_instance_in_process_env] 1'] = {
-    'assetsOrError': {
-        '__typename': 'AssetConnection',
-        'nodes': [
-            {
-                'key': {
-                    'path': [
-                        'a'
-                    ]
-                }
-            },
-            {
-                'key': {
-                    'path': [
-                        'b'
-                    ]
-                }
-            },
-            {
-                'key': {
-                    'path': [
-                        'c'
-                    ]
-                }
-            }
-        ]
-    }
-}
-
 snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[in_memory_instance_in_process_env] 1'] = {
     'assetsOrError': {
         '__typename': 'AssetConnection',
@@ -64,7 +35,7 @@ snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[in_memory_instance_in_
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[postgres_with_sync_run_launcher_in_process_env] 1'] = {
+snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[sqlite_with_default_run_launcher_managed_grpc_env] 1'] = {
     'assetsOrError': {
         '__typename': 'AssetConnection',
         'nodes': [
@@ -93,20 +64,6 @@ snapshots['TestAssetAwareEventLog.test_get_all_asset_keys[postgres_with_sync_run
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_asset_key_materialization[asset_aware_instance_in_process_env] 1'] = {
-    'assetOrError': {
-        'assetMaterializations': [
-            {
-                'materializationEvent': {
-                    'materialization': {
-                        'label': 'a'
-                    }
-                }
-            }
-        ]
-    }
-}
-
 snapshots['TestAssetAwareEventLog.test_get_asset_key_materialization[in_memory_instance_in_process_env] 1'] = {
     'assetOrError': {
         'assetMaterializations': [
@@ -121,21 +78,7 @@ snapshots['TestAssetAwareEventLog.test_get_asset_key_materialization[in_memory_i
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_asset_key_materialization[postgres_with_sync_run_launcher_in_process_env] 1'] = {
-    'assetOrError': {
-        'assetMaterializations': [
-            {
-                'materializationEvent': {
-                    'materialization': {
-                        'label': 'a'
-                    }
-                }
-            }
-        ]
-    }
-}
-
-snapshots['TestAssetAwareEventLog.test_get_asset_key_not_found[asset_aware_instance_in_process_env] 1'] = {
+snapshots['TestAssetAwareEventLog.test_get_asset_key_materialization[sqlite_with_default_run_launcher_managed_grpc_env] 1'] = {
     'assetOrError': {
         '__typename': 'AssetNotFoundError'
     }
@@ -147,27 +90,12 @@ snapshots['TestAssetAwareEventLog.test_get_asset_key_not_found[in_memory_instanc
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_asset_key_not_found[postgres_with_sync_run_launcher_in_process_env] 1'] = {
+snapshots['TestAssetAwareEventLog.test_get_asset_key_not_found[sqlite_with_default_run_launcher_managed_grpc_env] 1'] = {
     'assetOrError': {
         '__typename': 'AssetNotFoundError'
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization[asset_aware_instance_in_process_env] 1'] = {
-    'assetOrError': {
-        'assetMaterializations': [
-            {
-                'materializationEvent': {
-                    'materialization': {
-                        'label': 'a'
-                    }
-                },
-                'partition': 'partition_1'
-            }
-        ]
-    }
-}
-
 snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization[in_memory_instance_in_process_env] 1'] = {
     'assetOrError': {
         'assetMaterializations': [
@@ -183,7 +111,7 @@ snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization[postgres_with_sync_run_launcher_in_process_env] 1'] = {
+snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization[sqlite_with_default_run_launcher_managed_grpc_env] 1'] = {
     'assetOrError': {
         'assetMaterializations': [
             {
@@ -198,21 +126,6 @@ snapshots['TestAssetAwareEventLog.test_get_partitioned_asset_key_materialization
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_prefixed_asset_keys[asset_aware_instance_in_process_env] 1'] = {
-    'assetsOrError': {
-        '__typename': 'AssetConnection',
-        'nodes': [
-            {
-                'key': {
-                    'path': [
-                        'a'
-                    ]
-                }
-            }
-        ]
-    }
-}
-
 snapshots['TestAssetAwareEventLog.test_get_prefixed_asset_keys[in_memory_instance_in_process_env] 1'] = {
     'assetsOrError': {
         '__typename': 'AssetConnection',
@@ -228,7 +141,7 @@ snapshots['TestAssetAwareEventLog.test_get_prefixed_asset_keys[in_memory_instanc
     }
 }
 
-snapshots['TestAssetAwareEventLog.test_get_prefixed_asset_keys[postgres_with_sync_run_launcher_in_process_env] 1'] = {
+snapshots['TestAssetAwareEventLog.test_get_prefixed_asset_keys[sqlite_with_default_run_launcher_managed_grpc_env] 1'] = {
     'assetsOrError': {
         '__typename': 'AssetConnection',
         'nodes': [
